# Configuring a CERN machine

## CC7

A tool called `locmap` (Local Configuration with Masterless Puppet) helps to configure your machine with Linux support puppet modules and is installed by default with the CERN supported distributions.

### Usage

#### Show information about your machine and associated users

```
$ locmap --info
--------------
Configuration:
--------------
    Configuration directory  : /etc/locmap
    Configuration file       : /etc/locmap/locmap.conf
    Puppet modules path      : /usr/share/puppet/modules
    Puppet config path       : /etc/puppetlabs/puppet/
    Puppet hiera path        : /etc/locmap/code/environments/
    Puppet environment       : production
    Log directory            : /var/log

---------
Hostname:
---------
architecture:'x86_64'
created:'20160902091816.0Z'
domain:'cern.ch'
fqdn:'crabe.cern.ch'
hostname:'crabe'
ip:'128.141.193.232'
ip6:'fe80::6600:6aff:fe5e:899d'
is_virtual:'False'
location:'0031 1-0005'
mainusers:'set(['toulevey'])'
managedby:'set([])'
manager:'set([])'
modified:'20180704152445.0Z'
responsibles:'set(['toulevey'])'
uptime:'2'
cern_domain:default

------
Users:
------
 toulevey     IT-CM-LCS      Primary    31  thomas.oulevey@cern.ch
```

#### List available modules:

Here you can see all the different modules you can have configured by locmap. For instance, `afs` and `eosclient` will configure the AFS and EOS filesystems so that you can access them from your machine:

```
$ locmap --list
[Available Modules]
afs            [ enabled]
cernbox        [ enabled]
cvmfs          [ enabled]
eosclient      [ enabled]
kerberos       [ enabled]
lpadmin        [ enabled]
nscd           [ enabled]
ntp            [ enabled]
sendmail       [ enabled]
ssh            [ enabled]
sudo           [ enabled]
```

#### Enable and configure a module

```
$ locmap --enable afs
[INFO] module afs enabled.
```

Once enabled, we are able to actually configure AFS in our machine:
```
$ locmap --configure afs
[INFO    ] Please wait while your system is being configured...
[INFO    ] The run succeeded with no changes or failures; the system was already in the desired state.
```

You can check it by listing the contents of your personal folder:

```
ls /afs/cern.ch/user/u/username/
```
(NOTE: Substitute the u for the initial of your username, and username for your actual username)

## SLC6 (deprecated in November 2020)

`lcm` (Local Configuration Manager) is the equivalent of `locmap` on SLC6. It is using Quattor components to configure machines.

`lcm` is installed by default.

### Usage

#### List available components:

```
$ lcm --list

[INFO] LCM version 0.6 started by root at: Mon Nov 12 11:58:03 2018

[INFO] NCM-NCD version 1.2.23 started by root at: Mon Nov 12 11:58:03 2018
active components found inside profile /software/components:
name           file?  predeps                      postdeps
-------------------------------------------------------------------
sendmail:      yes
pine:          no
srvtab:        yes    ntpd,krb5clt
ssh:           yes
chkconfig:     yes
afsclt:        yes
ntpd:          yes
ocsagent:      yes
krb5clt:       yes
```

#### Configure one of the components

```
$ lcm --configure ntpd
[INFO] LCM version 0.6 started by root at: Mon Nov 12 12:01:51 2018

[INFO] NCM-NCD version 1.2.23 started by root at: Mon Nov 12 12:01:51 2018
[INFO] executing configure on components....


[INFO] running component: ntpd
---------------------------------------------------------
[INFO] configure on component ntpd executed, 0 errors, 0 warnings

=========================================================

[OK]   0 errors, 0 warnings executing configure
```
