# Yellowdog Updater Modified (YUM)

YUM, similarly to RPM, is a command-line package-management utility. It is different, and better, in that it allows for automatic updates and package and dependency management. Yum works with software repositories that allow for the updates, yet runs RPM underneath.

## YUM Basics

### Cleaning the  yum cache

YUM uses a cache to speed-up its operations, it is always a good idea to "clean" whenever you first log in to a machine:

```
yum clean all
```

### Retrieve information about your packages

In order to query packages available on your system:
```
yum list
```

Check installed kernel versions:
```
$ yum list kernel
kernel-3.10.0-862.11.6.el7.x86_64
kernel-3.10.0-862.14.4.el7.x86_64
```

Check if a file is part of an available package:
```
yum provides /usr/bin/korgac
Loaded plugins: changelog, fastestmirror, kernel-module, langpacks, protectbase, tsflags, versionlock
Loading mirror speeds from cached hostfile

[...]

7:kdepim-4.10.5-7.el7.x86_64 : KDE PIM (Personal Information Manager) applications
Repo        : @cr-testing
Matched from:
Filename    : /usr/bin/korgac
```

### Install a package

```
yum install wget
```

### Remove a package

```
yum remove wget
```

### Update all the installed packages in your system

```
yum update
```

## YUM repositories

The above commands are very similar to the ones shown in [RPM 101](./rpm.md). However, the true power of yum is managing packages through repositories.

A repository is a storage location where packages are stored, and thus can be retrieved and installed.

An example is the [CC7 CERN repository](http://linuxsoft.cern.ch/centos/7/updates/x86_64/Packages/), where one can find all CERN-related packages maintained by us.

Although the recommended way of configuring software repositories is using puppet (through the [CERN central configuration management service](https://gitlab.cern.ch/ai/it-puppet-module-osrepos/blob/master/code/README.md)) one might need to perform certain operations by hand:

Check the list of enabled repositories:
```
yum repolist
```

This will show the enabled repositories that YUM will be aware of in that system. If trying to install a certain package it is not found, you might want to add additional repositories where that packaged might be stored. CentOS default repositories are very minimal as it is a system meant for servers, so for instance not many GUI packages are in the default repositories.

YUM repositories are just files under `/etc/yum.repos.d` (if your system is not puppet managed), with a similar format:

```
cat /etc/yum.repos.d/cernbox.repo
[cernbox]
name=CERNBOX2.0 client repository (EOS backend)
baseurl=http://cernbox.cern.ch/cernbox/doc/Linux/repo/CentOS_7
enabled=1
gpgcheck=1
repo_gpgcheck=0
gpgkey=http://cernbox.cern.ch/cernbox/doc/Linux/repo/CentOS_7/repodata/repomd.xml.key
```

You can also check all configured repositories in your system (even if not enabled) running:

```
yum repolist all
```

And to enable a repository, you can do it either:

For the command you are running (temporarily):
```
yum --enablerepo=docker-ce-test/x86_64 install docker
```

Or permanently editing the corresponding `.repo` file, changing the `enabled=` param to `1`:

```
$ cat /etc/yum.repos.d/docker-ce.repo
[docker-ce-test]
[...]
enabled=1
[...]
```
